@@ -2,6 +2,7 @@ import os
 import sys
 import shutil
 import backstage
+import subprocess
 
 class Project():
     """A backstage project is a specific local install of backstage."""
@@ -107,7 +108,7 @@ class Project():
             raise
         return True
 
-def copy_project_skel(fullpath):
+def copy_project_skel(project_dir):
     """Populate a (usually) new backstage project with the contents of backstage/skel"""
     skeldir = os.path.join(os.path.dirname(backstage.__file__),'skel')
     if not os.path.exists(skeldir):
@@ -116,32 +117,26 @@ def copy_project_skel(fullpath):
         raise
     try:
         #Copy the contents of the 'base' folder into the project root
-        #typically will include 'project' and 'sites' folders + __init__.py
         skelbase=os.path.join(skeldir, 'base')
-        for f in os.listdir(skelbase):
-            infile = os.path.join(skelbase, f)
-            outfile = os.path.join(fullpath, f)
-            if os.path.isfile(infile):
-                shutil.copy(infile, outfile)
-            else:
-                shutil.copytree(infile, outfile)
+        subprocess.call("cp", "-rp", skelbase, project_dir)
+
     except:
-        s = "ERROR copying the project skel into %s" % fullpath
+        s = "ERROR copying the project skel into %s" % project_dir
         print s
         raise
     return True
 
 def new_project(project_name, project_path, source_ini_file = None):
         """create a new backstage project with the given name and located at the specified path"""
-        fullpath=os.path.abspath(os.path.join(project_path, project_name))
+        project_path = os.path.abspath(os.path.join(project_path, project_name))
         try:
-            os.makedirs(fullpath)
+            os.makedirs(project_path)
         except:
             print 'Error creating project.'
             raise
 
         try:
-            with open(os.path.join(fullpath, '__init__.py'), 'w'):
+            with open(os.path.join(project_path, '__init__.py'), 'w'):
                 pass
         except:
             err = 'ERROR with init file'
@@ -150,7 +145,7 @@ def new_project(project_name, project_path, source_ini_file = None):
         try:
             if source_ini_file is not None:
                 pass  #try to copy the file
-            fh=open(os.path.join(fullpath, 'backstage.ini'), 'w')
+            fh=open(os.path.join(project_path, 'backstage.ini'), 'w')
             fh.write('[backstage]\n')
             fh.close()
         except:
@@ -158,7 +153,7 @@ def new_project(project_name, project_path, source_ini_file = None):
             raise
 
         try:
-            copy_project_skel(fullpath)
+            copy_project_skel(project_path)
         except:
             s = 'Error in copy_project_skel'
             print s
@@ -167,7 +162,7 @@ def new_project(project_name, project_path, source_ini_file = None):
 
 
         try:
-            p = use_project(fullpath)
+            p = use_project(project_path)
         except:
             raise
         s = 'Successfully created Backstage project %s at %s' % (p.PROJECT_NAME, p.PROJECT_ROOT)
